@@ -1,6 +1,7 @@
 import pytest
 
 from pdffiller.pdf import Pdf
+from pdffiller.exceptions import PdfFillerException
 
 
 def test_valid_pdf(test_data_dir):
@@ -14,11 +15,11 @@ def test_valid_pdf(test_data_dir):
     assert schema[3]["FieldName"] == "Women"
     assert schema[4]["FieldName"] == "MaritalStatus"
     assert len(schema[4]["FieldOptions"]) == 4
-    assert schema[4]["FieldOptions"][0] == "Divorced"
-    assert schema[4]["FieldOptions"][1] == "Off"
-    assert schema[4]["FieldValue"] == "Married"
+    assert "Divorced" in schema[4]["FieldOptions"]
+    assert "Off" in schema[4]["FieldOptions"]
+    assert schema[4]["FieldValue"] == "Off"
 
 
 def test_invalid_pdf(test_data_dir):
-    reader = Pdf(str(test_data_dir / "empty.pdf"))
-    assert len(reader.widgets) == 0
+    with pytest.raises(PdfFillerException):
+        Pdf(str(test_data_dir / "empty.pdf"))
